==> webkit2gtk_2.51.1.orig.tar.xz: webkitgtk-2.51.1/Tools/TestWebKitAPI/Tests/WebKit Swift/Foundation+Extras.swift <==
// Copyright (C) 2024 Apple Inc. All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
// THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
// PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
// BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
// THE POSSIBILITY OF SUCH DAMAGE.

import Foundation

#if compiler(>=6.2)

extension RangeReplaceableCollection {
    init<Failure>(
        _ sequence: some AsyncSequence<Element, Failure>,
        isolation: isolated (any Actor)? = #isolation
    ) async throws(Failure) where Failure: Error {
        self.init()

        // Safety: this is actually safe; false positive is rdar://154775389
        for try await unsafe element in sequence {
            append(element)
        }
    }
}

extension AsyncSequence {
    func wait(isolation: isolated (any Actor)? = #isolation) async throws(Failure) {
        // Safety: this is actually safe; false positive is rdar://154775389
        for try await unsafe _ in self {
        }
    }
}

#endif // compiler(>=6.2)

==> webkit2gtk_2.51.4.orig.tar.xz: webkitgtk-2.51.4/Tools/TestWebKitAPI/Tests/WebKit Swift/Foundation+Extras.swift <==
// Copyright (C) 2024 Apple Inc. All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
// THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
// PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
// BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
// CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
// SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
// CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
// THE POSSIBILITY OF SUCH DAMAGE.

import Foundation

typealias String = Swift.String
typealias URL = Foundation.URL

#if compiler(>=6.2)

@available(macOS 15.0, iOS 18.0, *)
extension RangeReplaceableCollection {
    init<Failure>(
        _ sequence: some AsyncSequence<Element, Failure>,
        isolation: isolated (any Actor)? = #isolation
    ) async throws(Failure) where Failure: Error {
        self.init()

        // Safety: this is actually safe; false positive is rdar://154775389
        for try await unsafe element in sequence {
            append(element)
        }
    }
}

@available(macOS 15.0, iOS 18.0, *)
extension AsyncSequence {
    func wait(isolation: isolated (any Actor)? = #isolation) async throws(Failure) {
        // Safety: this is actually safe; false positive is rdar://154775389
        for try await unsafe _ in self {
        }
    }
}

#endif // compiler(>=6.2)
